from decimal import Decimal


def numeric2str_convertor(arg):
    v = str(arg)
    if v.find('E'):
        v = '{:.8f}'.format(Decimal(v))
    nums = v.split('.')
    if int(nums[1]) == 0:
        result = nums[0]
    else:
        num = str(int(nums[1][::-1]))
        result = '{}.{}'.format(nums[0], num[::-1])
    return result



from operator import setitem

import scrapy


def attr_settler(cls, obj):
    item = cls()
    if not isinstance(item, scrapy.Item):
        msg = ("(%s) is not supported now, we only support the types in items.py. Let sb knows if you want others." %
               type(item).__name__)
        raise Exception(msg)
    field_keys = item.fields.keys()
    for key in field_keys:
        if key in obj:
            v = obj[key]
            if key == 'id':
                #  MongoDB can only handle up to 8-byte ints
                v = str(v)
            setitem(item, key, v)
    return item



from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='common-utilities',
    version='0.0.5',
    description="Common utilities",
    long_description=open('README.md', 'r').read(),
    long_description_content_type="text/markdown",
    url='',
    author='hacfox',
    author_email='zz.hacfox@gmail.com',
    packages=find_packages(exclude=[]),
    classifiers=[
        'Programming Language :: Python :: 3',
    ],
    install_requires=[],
    zip_safe=True
)
